@@ -3,7 +3,7 @@ package Net::Curl::Promiser;
 use strict;
 use warnings;
 
-our $VERSION = '0.09_01';
+our $VERSION = '0.09_02';
 
 =encoding utf-8
 
@@ -149,9 +149,12 @@ sub add_handle {
         die "bad promise engine: [$env_engine]";
     }
     else {
-        my $module = $self->PROMISE_CLASS() . '.pm';
-        $module =~ s<::></>g;
-        require $module;
+        $self->PROMISE_CLASS()->can('new') or do {
+            my $class = $self->PROMISE_CLASS();
+
+            local $@;
+            die if !eval "require $class";
+        };
 
         $promise = $self->PROMISE_CLASS()->new( sub {
             $self->{'callbacks'}{$easy} = \@_;
